@@ -3,7 +3,7 @@ import os
 
 from flask_migrate import Migrate
 from flask_script import Manager, Shell
-from notejob.center.app import create_app, db
+from notejob.center.app.core import create_app, db
 from notejob.center.datas.model.cron_infos import CronInfos
 from notejob.center.datas.model.job_log import JobLog
 from notejob.center.datas.model.job_log_items import JobLogItems
